{
Client Access Objects 1.5

caoDatabaseSQLCA component

(c) 1998, 1999 Steven P. Goldsmith
All Rights Reserved

The cwbDatabaseSQLCA automation object holds the information contained in the
SQLCA communications area and gives the state of an SQL statement.  This object
is to be used in conjunction with a cwbDatabaseSQL object.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 1, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

sgoldsmith@home.com
http://members.home.net/sgoldsmith/
}

unit caoDatabaseSQLCA;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,

  // Import type library "Client Access Object Library" before installing.

  Cwbautsv_TLB;

type

  // caoDatabaseSQLCA exception object

  EcaoDatabaseSQLCA = class(Exception);

  TcaoDatabaseSQLCA = class(TComponent)
  private
    { Private declarations }
    FReturnCode: integer;
    FcwbDatabaseSQLCA: cwbDatabaseSQLCA;
    function GetSQLCode: integer;
    function GetSqlErrml: SmallInt;
    function GetSqlErrp: WideString;
    function GetSqlErrd1: integer;
    function GetSqlErrd2: integer;
    function GetSqlErrd3: integer;
    function GetSqlErrd4: integer;
    function GetSqlErrd5: integer;
    function GetSqlErrd6: integer;
    function GetSqlWarn: WideString;
  protected
    { Protected declarations }
    function ResultCodeText: string; virtual;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    procedure GetSqlerrmc(var dataBuf: OleVariant; var dataLen: Smallint); virtual;
    procedure SetSqlerrmc(dataBuf: OleVariant; dataLen: Smallint); virtual;
  published
    { Published declarations }
    property ReturnCode: integer read FReturnCode default cwbOK;
    property sqlcode: integer read GetSqlCode;
    property sqlerrml: SmallInt read GetSqlErrml;
    property sqlerrp: WideString read GetSqlErrp;
    property sqlerrd1: integer read GetSqlErrd1;
    property sqlerrd2: integer read GetSqlErrd2;
    property sqlerrd3: integer read GetSqlErrd3;
    property sqlerrd4: integer read GetSqlErrd4;
    property sqlerrd5: integer read GetSqlErrd5;
    property sqlerrd6: integer read GetSqlErrd6;
    property sqlwarn: WideString read GetSqlWarn;
    property OleObject: cwbDatabaseSQLCA read FcwbDatabaseSQLCA;
  end;

implementation

{
Create OLE object and initilize properties.
}

constructor TcaoDatabaseSQLCA.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FcwbDatabaseSQLCA := CocwbDatabaseSQLCA.Create
end;

{
Return formatted result code text.
}

function TcaoDatabaseSQLCA.ResultCodeText: string;
begin
  Result := Format('Result code %d',[FReturnCode])
end;

{
This property contains the SQLCA return code.  Possible values are:

0 - Successful execution, although SQLWARN indicators might have been set.
Positive number - Successful execution with a warning condition.
Negative number - Error condition.

This is a read-only property.
}

function TcaoDatabaseSQLCA.GetSQLCode: integer;
begin
  Result := FcwbDatabaseSQLCA.sqlcode
end;

{
This property contains the length of the SQLCA return code accessible by the
cwbdbGetSqlerrmc method.  Valid values are from zero to 70.  If the value is
zero, calling the cwbdbGetSqlerrmc is not valid.  This is a read-only property.
}

function TcaoDatabaseSQLCA.GetSqlErrml: SmallInt;
begin
  Result := FcwbDatabaseSQLCA.sqlerrml
end;

{
This property contains the name of the product and module returning the error.
The first three characters identify the product, which is QSQ for SQL/400.
This is a read-only property.
}

function TcaoDatabaseSQLCA.GetSqlErrp: WideString;
begin
  Result := FcwbDatabaseSQLCA.sqlerrp
end;

{
This property contains the last four characters of the CPF escape message, if
sqlcode is non-zero.  This is a read-only property.
}

function TcaoDatabaseSQLCA.GetSqlErrd1: integer;
begin
  Result := FcwbDatabaseSQLCA.sqlerrd1
end;

{
This property contains the last four characters of a CPD diagnostic message, if
the sqlcode is less than zero.  This is a read-only property.
}

function TcaoDatabaseSQLCA.GetSqlErrd2: integer;
begin
  Result := FcwbDatabaseSQLCA.sqlerrd2
end;

{
This property shows the number of rows affected after INSERT, UPDATE, and
DELETE.  This is a read-only property.
}

function TcaoDatabaseSQLCA.GetSqlErrd3: integer;
begin
  Result := FcwbDatabaseSQLCA.sqlerrd3
end;

{
This property contains the row length for a blocked FETCH statement.  This is
a read-only property.
}

function TcaoDatabaseSQLCA.GetSqlErrd4: integer;
begin
  Result := FcwbDatabaseSQLCA.sqlerrd4
end;

{
This property contains the position of the syntax error for a PREPARE or
EXECUTE IMMEDIATE statement.  For a CONNECT statemnet, zero indicates the
connection is local.  -1 indicates the disconnected state, and one indicates
the connection is remote.  On a blocked FETCH statement, it contains 100, if
an end-of-file is detected.  This is a read-only property.
}

function TcaoDatabaseSQLCA.GetSqlErrd5: integer;
begin
  Result := FcwbDatabaseSQLCA.sqlerrd5
end;

{
This property contains the SQL completion message identifier, when sqlcode is
zero.  Otherwise, it is undefined.  This is a read-only property.
}

function TcaoDatabaseSQLCA.GetSqlErrd6: integer;
begin
  Result := FcwbDatabaseSQLCA.sqlerrd6
end;

{
This property contains a set of eleven warning indicators each containing
blank, W or N as follows:

1	Blank if all other indicators are blank; contains W if at least one
        other indicator contains W or N.
2	Contains W if the value of a string column was truncated when assigned
        to a host variable.  Contains N if *NOCNULRQD was specified on the
        CRTSQLC command and, the value of a string column was assigned to a C
        NULL-terminated host variable and the host variable was large enough to
        contain the result but not large enough to contain the NULL-terminator.
3	Contains W if the null values were eliminated from the argument of a
        function; not necessarily set to W for the MIN function because its
        results are not dependent on the elimination of null values.
4	Contains W if the number of columns is larger than the number of host
        variables.
5	Contains W if a prepared UPDATE or DELETE statement does not include a
        WHERE clause.
6	Reserved
7	Contains W if date arithmetic results in an end-of-month adjustment.
8	Reserved
9	Contains W if the result of a character conversion contains the
        substitution character.
10	Reserved
11	Reserved
}

function TcaoDatabaseSQLCA.GetSqlWarn: WideString;
begin
  Result := FcwbDatabaseSQLCA.sqlwarn
end;

{
This method returns the message replacement text associated with the sqlcode.
Parameters:
dataBuf - Byte Array Variant
Points to a buffer where the message replacement text should be stored.  (This
should be passed as a SafeArray of unisgned characters.)
dataLen - Pointer to Short Integer
Used to store the length of the replacement text stored in dataBuf, on output.
}

procedure TcaoDatabaseSQLCA.GetSqlerrmc(var dataBuf: OleVariant; var dataLen: Smallint);
begin
  FReturnCode := FcwbDatabaseSQLCA.cwbdbGetSqlerrmc(
  dataBuf,dataLen);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseSQLCA.Create(ResultCodeText)
end;

{
This method sets the message replacement text associated with the sqlcode.
Parameters:
dataBuf - Byte Array Variant
Points to a buffer where the message replacement text should be stored.  (This
should be passed as a SafeArray of unisgned characters.)
dataLen - Pointer to Short Integer
Used to store the length of the replacement text stored in dataBuf, on input.
}

procedure TcaoDatabaseSQLCA.SetSqlerrmc(dataBuf: OleVariant; dataLen: Smallint);
begin
  FReturnCode := FcwbDatabaseSQLCA.cwbdbSetSqlerrmc(
  dataBuf,dataLen);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseSQLCA.Create(ResultCodeText)
end;

end.
